@@ -14,7 +14,7 @@ Readonly::Array our @EXPORT_OK => qw(attribute char comment end_element instruct
 	start_element);
 
 # Version.
-our $VERSION = 0.03;
+our $VERSION = 0.04;
 
 # Encode attribute as PYX.
 sub attribute {
@@ -162,12 +162,13 @@ L<Readonly>.
 
 =head1 SEE ALSO
 
-L<PYX::GraphViz>,
-L<PYX::Hist>,
-L<PYX::Parser>,
-L<PYX::Stack>,
-L<PYX::Utils>,
-L<Task::PYX>.
+=over
+
+=item L<Task::PYX>
+
+Install the PYX modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -186,6 +187,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.03
+0.04
 
 =cut
